@@ -23,7 +23,7 @@ import os
 import os.path
 import glob
 
-__version__ = "1.1"
+__version__ = "1.2.1"
 
 class MSCLexer(object):
     """Lexer class"""
@@ -189,6 +189,7 @@ class MSCLexer(object):
             "MULTIPART_INVALID_HEADER_FOLDING",
             "MULTIPART_INVALID_PART",
             "MULTIPART_FILE_LIMIT_EXCEEDED",
+            "MULTIPART_PART_HEADERS",
             "OUTBOUND_DATA_ERROR",
             "PATH_INFO",
             "PERF_ALL",
@@ -381,8 +382,8 @@ class MSCLexer(object):
         aff_line = a_data[li]
         pos = t.lexer.lexpos - pos_data[li]
         output = ("Lexer error: illegal token found in line %d at pos %d, column %d\n%s\n%s^" % \
-                    (li, t.lexer.lexpos, pos, aff_line, (pos * "~")))
-        raise Exception(output)
+                    (li+1, t.lexer.lexpos, pos, aff_line, (pos * "~")))
+        raise Exception(output, {'cause': "lexer", 'line': li+1, 'position': t.lexer.lexpos, 'column': pos})
 
 # END Generic error handling
 
@@ -652,7 +653,7 @@ class MSCLexer(object):
                     return 'T_CONFIG_DIRECTIVE_SECACTION'
                 t.lexer.begin('STCONFIGDIRECTIVE')
                 return 'T_CONFIG_DIRECTIVE'
-        return None
+        self.t_ANY_error(t)
 
     def parse_config_directive_argument(self, t):
         if t.value[0] == '"' and t.value[-1] == '"':
@@ -673,8 +674,7 @@ class MSCLexer(object):
             if d.lower() == t.value.lower():
                 t.lexer.begin('STSECRULEVARIABLE')
                 return 'T_SECRULE_VARIABLE'
-
-        return None
+        self.t_ANY_error(t)
 
     def parse_config_secrule_operator(self, t):
         if t.value[0] == "!" and t.value[1] == '@':
@@ -700,7 +700,7 @@ class MSCLexer(object):
         for d in self.default_secrule_actions:
             if d.lower() == t.value.lower():
                 return 'T_SECRULE_ACTION'
-        return None
+        self.t_ANY_error(t)
 
 # END Helper functions for scanner
 # END Lexer class
@@ -902,7 +902,7 @@ class MSCParser(object):
 
     def p_secrule_variable_counter_only(self, p):
         """secrule_variable_counter_only : T_SECRULE_VARIABLE_COUNTER T_SECRULE_VARIABLE"""
-        self.secrule['variables'].append({'variable': p[2], 'variable_part': "", 'quote_type': "", 'negated': False, 'counter': True})
+        self.secrule['variables'].append({'variable': p[2], 'variable_part': "", 'quote_type': "no_quote", 'negated': False, 'counter': True})
 
     def p_secrule_variable_counter_with_var(self, p):
         """secrule_variable_counter_with_var : T_SECRULE_VARIABLE_COUNTER T_SECRULE_VARIABLE T_SECRULE_VARIABLE_PART
@@ -1038,7 +1038,7 @@ class MSCParser(object):
             pos = p.lexer.lexpos - pos_data[li]
             output = ("Parser error: syntax error in line %d at pos %d, column %d\n%s\n%s^" % \
                     (li+1, p.lexer.lexpos, pos, aff_line, (pos * "~")))
-            raise Exception(output)
+            raise Exception(output, {'cause': "parser", 'line': li+1, 'position': p.lexer.lexpos, 'column': pos})
         else:
             secrule = {}
 
